@@ -16,7 +16,7 @@ def complete():
     Benchmark_2gpu()
     Benchmark_3gpu()
     
-    subprocess.check_call('for x in ./job_script*; do mkdir "${x}".d && mv "$x" "${x}".d; done;for f in *.d; do mv -n -- "$f" "${f%.d}"; done;for file in job_*; do mv "$file" "${file#job_}";done;for i in ./*; do cp ../*.tpr ${i}/; done;for d in ./*/ ; do (cd "$d" && sbatch job_script*); done',shell=True)
+    subprocess.check_call('for x in ./job_script*; do mkdir "${x}".d && mv "$x" "${x}".d; done;for f in *.d; do mv -n -- "$f" "${f%.d}"; done;for file in job_*; do mv "$file" "${file#job_}";done;for i in ./*; do cp ../*.tpr ${i}/; done;for i in script_*; do cp *.tpr ${i}/; done;for d in ./*/ ; do (cd "$d" && sbatch job_script*); done',shell=True)
     subprocess.check_call('squeue -n bingo > file.txt', shell=True)
     
     time_count()
